CFX-DB
======

CFX-DB is a CrossbarFX Python support package with core database access classes
written in native Python. The package allows direct in-memory data access from
Python programs (*including Jupyter notebooks!*) to CrossbarFX edge node data:

* persisted event history
* persisted tracing data
* XBR market maker transaction logs
* WAMP session cache


Installation
------------

To install CFX-DB:

.. code-block:: console

    pip install cfxdb

